import { Token } from '@lumino/coreutils';
import { IPlugin } from '@lumino/application';
import { ServiceManager } from '@jupyterlab/services';
import { PluginTranspiler } from './transpiler';
import { IRequireJS } from './requirejs';
import { IModule, IModuleMember } from './types';
export declare namespace PluginLoader {
    interface IOptions {
        transpiler: PluginTranspiler;
        importFunction(statement: string): Promise<Token<any> | IModule | IModuleMember>;
        tokenMap: Map<string, Token<any>>;
        /**
         * For backward-compatibility with plugins using requirejs over `import`;
         */
        requirejs: IRequireJS;
        serviceManager: ServiceManager | null;
    }
    interface IResult {
        plugin: IPlugin<any, any>;
        code: string;
        transpiled: boolean;
        schema?: string | null;
    }
}
export declare class PluginLoader {
    private _options;
    constructor(options: PluginLoader.IOptions);
    loadFile(code: string): Promise<IModule>;
    private _createAsyncFunctionModule;
    private _discoverSchema;
    /**
     * Create a plugin from TypeScript code.
     */
    load(code: string, basePath: string | null): Promise<PluginLoader.IResult>;
}
export declare class PluginLoadingError extends Error {
    error: Error;
    partialResult: Omit<PluginLoader.IResult, 'plugin'>;
    constructor(error: Error, partialResult: Omit<PluginLoader.IResult, 'plugin'>);
}
